$Title Sets Definition
$ontext
--------------------------------------------------------------------------------
------------------------------ General Header ----------------------------------
--------------------------------------------------------------------------------
         Hybrid Top-down Computable General Equilibrium and Bottom-up Electricity Expansion Model
         Renato Rodrigues
         Instituto de Investigacin Tecnolgica
         Date: 26, may, 2011
--------------------------------------------------------------------------------
--------------------------- End of General Header ------------------------------
--------------------------------------------------------------------------------
$offtext

*-------------------------------------------------------------------------------
*------------------------------- Defining Options ------------------------------
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
*------------------------------ Solver definition ------------------------------
*-------------------------------------------------------------------------------
option LP=CPLEX;
option NLP=CONOPT;
option MCP=PATH;

*-------------------------------------------------------------------------------
*-------------------- Enable export results to excel files ---------------------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF
$set excel_export 1

*-------------------------------------------------------------------------------
*------------------------ Choose the years to be simulated ---------------------
*-------------------------------------------------------------------------------
*Defining years of execution
sets
	y        years           / 1900*2100 /
    ey(y)        execution year  (for CGE model)                                         /2005/
    eys(y)       execution years (for electricity model)                                 /2005*2020/;

*-------------------------------------------------------------------------------
*---------- Choose the costs to be considered in the electricity model ---------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF
Scalars
       exec_fc           Fuel costs                                                      /1/
       exec_co2          CO2 emission costs                                              /1/
*preciso revisar desagregacao porque no esto saindo valores aceitaveis quando considero co2

       exec_vom          Operation and maintenance variable equipaments reposition costs /1/
       exec_oem_equip    Operation and maintenance equipments fixed costs                /1/
       exec_oem_labor    Operation and maintenance labor fixed costs                     /1/
       exec_oem_sc       Operation and maintenance social contribution fixed costs       /1/
       exec_capac        Installed capacity amortization costs paid in the year          /1/
       exec_emiss_rights Technology emission rights distributed by the government        /1/
       exec_renew_prem   Renewable premium income                                        /0/;


*-------------------------------------------------------------------------------
*------------------------ Choose the location to be considered in the models ---------------------
*-------------------------------------------------------------------------------
*Defining locations of execution (I am having problems with extra peninsular location due to the high level of non-paid capacity; therefore its execution should be maintained null for the time being)
Set      l               Peninsular only electricity market                              /Peninsular/;
*set      l               Peninsular and Extra Peninsular electricity markets             /Peninsular, Extra Peninsular/;

alias (l,l_alias);

*-------------------------------------------------------------------------------
*---------------------- Choose the DR policy to be evaluated -------------------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF
Scalars
*Active Demand Management policy
       exec_DR_displac Demand reponse with load displacements                            /1/
       exec_DR_reduc   Demand reponse with load conservation savings                     /1/;

*-------------------------------------------------------------------------------
*------- Choose the objective fucnction of the SAM disaggregation scheme -------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF  (choose only one of the bellow alternatives)
Scalars
       exec_MinMax       MinMax deviation                                                /0/
       exec_MinMax_plus_lineal_term MinMax with additional term to exclude unnecessary deviations /0/
       exec_Quadratic   Min the squared deviation                                       /1/;

*-------------------------------------------------------------------------------
*------------------- Choose the CGE model type - MCP or NLP --------------------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF (choose only one of the bellow alternatives)
Scalars
       exec_MCP          CGE soved as a mixed complementarity problem                    /1/
       exec_NLP          CGE solved as a non lineal problem                              /0/;


*-------------------------------------------------------------------------------
*------------------- Choose the BU model type - MCP or LP ----------------------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF (choose only one of the bellow alternatives)
Scalars
       exec_BU_MCP       CGE soved as a mixed complementarity problem                    /0/
       exec_BU_LP        CGE solved as a lineal problem                                  /1/;


*-------------------------------------------------------------------------------
*-------------------------- Load segments aggregation --------------------------
*-------------------------------------------------------------------------------
sets
month / january,february,march,april,may,june,july,august,september,october,november,december /
day / 1*31 /
hour / 1*25 /
daytype / Working,Holiday /
weekday / Monday,Tuesday,Wednesday,Thursday,Friday,Saturday,Sunday /
p period load segment / month1_Monday_and_Friday_Working,month1_Tuesday_Wednesday_and_Thursday_Working,month1_Holidays,month2_Monday_and_Friday_Working,month2_Tuesday_Wednesday_and_Thursday_Working,month2_Holidays,month3_Monday_and_Friday_Working,month3_Tuesday_Wednesday_and_Thursday_Working,month3_Holidays,month4_Monday_and_Friday_Working,month4_Tuesday_Wednesday_and_Thursday_Working,month4_Holidays,month5_Monday_and_Friday_Working,month5_Tuesday_Wednesday_and_Thursday_Working,month5_Holidays,month6_Monday_and_Friday_Working,month6_Tuesday_Wednesday_and_Thursday_Working,month6_Holidays,month7_Monday_and_Friday_Working,month7_Tuesday_Wednesday_and_Thursday_Working,month7_Holidays,month8_Monday_and_Friday_Working,month8_Tuesday_Wednesday_and_Thursday_Working,month8_Holidays,month9_Monday_and_Friday_Working,month9_Tuesday_Wednesday_and_Thursday_Working,month9_Holidays,month10_Monday_and_Friday_Working,month10_Tuesday_Wednesday_and_Thursday_Working,month10_Holidays,month11_Monday_and_Friday_Working,month11_Tuesday_Wednesday_and_Thursday_Working,month11_Holidays,month12_Monday_and_Friday_Working,month12_Tuesday_Wednesday_and_Thursday_Working,month12_Holidays /
load_segment_definition(p,month,daytype,weekday) / month1_Monday_and_Friday_Working.january.Working.Friday,month1_Monday_and_Friday_Working.january.Working.Monday,month1_Tuesday_Wednesday_and_Thursday_Working.january.Working.Thursday,month1_Tuesday_Wednesday_and_Thursday_Working.january.Working.Tuesday,month1_Tuesday_Wednesday_and_Thursday_Working.january.Working.Wednesday,month1_Holidays.january.Holiday.Friday,month1_Holidays.january.Holiday.Monday,month1_Holidays.january.Holiday.Saturday,month1_Holidays.january.Holiday.Sunday,month1_Holidays.january.Holiday.Thursday,month1_Holidays.january.Holiday.Tuesday,month1_Holidays.january.Holiday.Wednesday,month2_Monday_and_Friday_Working.february.Working.Friday,month2_Monday_and_Friday_Working.february.Working.Monday,month2_Tuesday_Wednesday_and_Thursday_Working.february.Working.Thursday,month2_Tuesday_Wednesday_and_Thursday_Working.february.Working.Tuesday,month2_Tuesday_Wednesday_and_Thursday_Working.february.Working.Wednesday,month2_Holidays.february.Holiday.Friday,month2_Holidays.february.Holiday.Monday,month2_Holidays.february.Holiday.Saturday,month2_Holidays.february.Holiday.Sunday,month2_Holidays.february.Holiday.Thursday,month2_Holidays.february.Holiday.Tuesday,month2_Holidays.february.Holiday.Wednesday,month3_Monday_and_Friday_Working.march.Working.Friday,month3_Monday_and_Friday_Working.march.Working.Monday,month3_Tuesday_Wednesday_and_Thursday_Working.march.Working.Thursday,month3_Tuesday_Wednesday_and_Thursday_Working.march.Working.Tuesday,month3_Tuesday_Wednesday_and_Thursday_Working.march.Working.Wednesday,month3_Holidays.march.Holiday.Friday,month3_Holidays.march.Holiday.Monday,month3_Holidays.march.Holiday.Saturday,month3_Holidays.march.Holiday.Sunday,month3_Holidays.march.Holiday.Thursday,month3_Holidays.march.Holiday.Tuesday,month3_Holidays.march.Holiday.Wednesday,month4_Monday_and_Friday_Working.april.Working.Friday,month4_Monday_and_Friday_Working.april.Working.Monday,month4_Tuesday_Wednesday_and_Thursday_Working.april.Working.Thursday,month4_Tuesday_Wednesday_and_Thursday_Working.april.Working.Tuesday,month4_Tuesday_Wednesday_and_Thursday_Working.april.Working.Wednesday,month4_Holidays.april.Holiday.Friday,month4_Holidays.april.Holiday.Monday,month4_Holidays.april.Holiday.Saturday,month4_Holidays.april.Holiday.Sunday,month4_Holidays.april.Holiday.Thursday,month4_Holidays.april.Holiday.Tuesday,month4_Holidays.april.Holiday.Wednesday,month5_Monday_and_Friday_Working.may.Working.Friday,month5_Monday_and_Friday_Working.may.Working.Monday,month5_Tuesday_Wednesday_and_Thursday_Working.may.Working.Thursday,month5_Tuesday_Wednesday_and_Thursday_Working.may.Working.Tuesday,month5_Tuesday_Wednesday_and_Thursday_Working.may.Working.Wednesday,month5_Holidays.may.Holiday.Friday,month5_Holidays.may.Holiday.Monday,month5_Holidays.may.Holiday.Saturday,month5_Holidays.may.Holiday.Sunday,month5_Holidays.may.Holiday.Thursday,month5_Holidays.may.Holiday.Tuesday,month5_Holidays.may.Holiday.Wednesday,month6_Monday_and_Friday_Working.june.Working.Friday,month6_Monday_and_Friday_Working.june.Working.Monday,month6_Tuesday_Wednesday_and_Thursday_Working.june.Working.Thursday,month6_Tuesday_Wednesday_and_Thursday_Working.june.Working.Tuesday,month6_Tuesday_Wednesday_and_Thursday_Working.june.Working.Wednesday,month6_Holidays.june.Holiday.Friday,month6_Holidays.june.Holiday.Monday,month6_Holidays.june.Holiday.Saturday,month6_Holidays.june.Holiday.Sunday,month6_Holidays.june.Holiday.Thursday,month6_Holidays.june.Holiday.Tuesday,month6_Holidays.june.Holiday.Wednesday,month7_Monday_and_Friday_Working.july.Working.Friday,month7_Monday_and_Friday_Working.july.Working.Monday,month7_Tuesday_Wednesday_and_Thursday_Working.july.Working.Thursday,month7_Tuesday_Wednesday_and_Thursday_Working.july.Working.Tuesday,month7_Tuesday_Wednesday_and_Thursday_Working.july.Working.Wednesday,month7_Holidays.july.Holiday.Friday,month7_Holidays.july.Holiday.Monday,month7_Holidays.july.Holiday.Saturday,month7_Holidays.july.Holiday.Sunday,month7_Holidays.july.Holiday.Thursday,month7_Holidays.july.Holiday.Tuesday,month7_Holidays.july.Holiday.Wednesday,month8_Monday_and_Friday_Working.august.Working.Friday,month8_Monday_and_Friday_Working.august.Working.Monday,month8_Tuesday_Wednesday_and_Thursday_Working.august.Working.Thursday,month8_Tuesday_Wednesday_and_Thursday_Working.august.Working.Tuesday,month8_Tuesday_Wednesday_and_Thursday_Working.august.Working.Wednesday,month8_Holidays.august.Holiday.Friday,month8_Holidays.august.Holiday.Monday,month8_Holidays.august.Holiday.Saturday,month8_Holidays.august.Holiday.Sunday,month8_Holidays.august.Holiday.Thursday,month8_Holidays.august.Holiday.Tuesday,month8_Holidays.august.Holiday.Wednesday,month9_Monday_and_Friday_Working.september.Working.Friday,month9_Monday_and_Friday_Working.september.Working.Monday,month9_Tuesday_Wednesday_and_Thursday_Working.september.Working.Thursday,month9_Tuesday_Wednesday_and_Thursday_Working.september.Working.Tuesday,month9_Tuesday_Wednesday_and_Thursday_Working.september.Working.Wednesday,month9_Holidays.september.Holiday.Friday,month9_Holidays.september.Holiday.Monday,month9_Holidays.september.Holiday.Saturday,month9_Holidays.september.Holiday.Sunday,month9_Holidays.september.Holiday.Thursday,month9_Holidays.september.Holiday.Tuesday,month9_Holidays.september.Holiday.Wednesday,month10_Monday_and_Friday_Working.october.Working.Friday,month10_Monday_and_Friday_Working.october.Working.Monday,month10_Tuesday_Wednesday_and_Thursday_Working.october.Working.Thursday,month10_Tuesday_Wednesday_and_Thursday_Working.october.Working.Tuesday,month10_Tuesday_Wednesday_and_Thursday_Working.october.Working.Wednesday,month10_Holidays.october.Holiday.Friday,month10_Holidays.october.Holiday.Monday,month10_Holidays.october.Holiday.Saturday,month10_Holidays.october.Holiday.Sunday,month10_Holidays.october.Holiday.Thursday,month10_Holidays.october.Holiday.Tuesday,month10_Holidays.october.Holiday.Wednesday,month11_Monday_and_Friday_Working.november.Working.Friday,month11_Monday_and_Friday_Working.november.Working.Monday,month11_Tuesday_Wednesday_and_Thursday_Working.november.Working.Thursday,month11_Tuesday_Wednesday_and_Thursday_Working.november.Working.Tuesday,month11_Tuesday_Wednesday_and_Thursday_Working.november.Working.Wednesday,month11_Holidays.november.Holiday.Friday,month11_Holidays.november.Holiday.Monday,month11_Holidays.november.Holiday.Saturday,month11_Holidays.november.Holiday.Sunday,month11_Holidays.november.Holiday.Thursday,month11_Holidays.november.Holiday.Tuesday,month11_Holidays.november.Holiday.Wednesday,month12_Monday_and_Friday_Working.december.Working.Friday,month12_Monday_and_Friday_Working.december.Working.Monday,month12_Tuesday_Wednesday_and_Thursday_Working.december.Working.Thursday,month12_Tuesday_Wednesday_and_Thursday_Working.december.Working.Tuesday,month12_Tuesday_Wednesday_and_Thursday_Working.december.Working.Wednesday,month12_Holidays.december.Holiday.Friday,month12_Holidays.december.Holiday.Monday,month12_Holidays.december.Holiday.Saturday,month12_Holidays.december.Holiday.Sunday,month12_Holidays.december.Holiday.Thursday,month12_Holidays.december.Holiday.Tuesday,month12_Holidays.december.Holiday.Wednesday /;

Scalar
       UseLoadBlockAggregation                                                           /1/;
Set b load blocks /SuperOffPeak,OffPeak,Medium,Peak,SuperPeak/;

Parameters
Block_min_percentil(b) /SuperOffPeak 0,OffPeak 5,Medium 30,Peak 70,SuperPeak 95/
Block_max_percentil(b) /SuperOffPeak 5,OffPeak 30,Medium 70,Peak 95,SuperPeak 100/;

***********************************************************************************************************************************************************
